@@ -5,9 +5,9 @@ use Carp qw(longmess shortmess);
 use parent 'Exporter';
 use overload bool => sub {1}, q{""} => 'scalar', fallback => 1;
 
-our @EXPORT = qw(bleep ouch kiss hug);
-our @EXPORT_OK = qw(try throw catch catch_all);
-our %EXPORT_TAGS = ( traditional => [qw( throw catch try catch_all )] );
+our @EXPORT = qw(bleep ouch kiss hug barf);
+our @EXPORT_OK = qw(try throw catch catch_all caught caught_all);
+our %EXPORT_TAGS = ( traditional => [qw(try throw catch catch_all)], trytiny => [qw( throw caught caught_all )] );
 
 sub new {
   my ($class, $code, $message, $data) = @_;
@@ -43,6 +43,10 @@ sub catch {
   kiss @_;
 }
 
+sub caught {
+  kiss @_;
+}
+
 sub hug {
   my ($e) = @_;
   $e ||= $@;
@@ -53,6 +57,10 @@ sub catch_all {
   hug @_;
 }
 
+sub caught_all {
+  hug @_;
+}
+
 sub bleep {
   my ($e) = @_;
   $e ||= $@;
@@ -70,6 +78,21 @@ sub bleep {
   }
 }
 
+sub barf {
+    my ($e) = @_;
+    my $code;
+    $e ||= $@;
+    if (ref $e eq 'Ouch') {
+        $code = $e->code;
+    } 
+    else {
+        $code = 1;
+    }
+
+    print STDERR bleep($e)."\n";
+    exit $code;
+}
+
 sub scalar {
   my $self = shift;
   return $self->{shortmess};
@@ -257,6 +280,18 @@ Optional. If you like you can pass the exception into C<bleep>. If not, it will
 
 =back
 
+=head3
+
+Calls C<bleep>, and then exits with error code
+
+=over
+
+=item exception
+
+Optional. You can pass an exception into C<barf> which then gets passed to C<bleep> otherwise it will use whatever's in C<$@>
+
+=back
+
 
 =head2 Object-Oriented Interface
 
@@ -308,7 +343,7 @@ Returns the C<data> passed into the constructor.
 
 =head2 Traditional Interface
 
-Some people just can't bring themselves to use the sugary cuteness of Ouch. For them there is the traditional interface. Here's how it works:
+Some people just can't bring themselves to use the sugary cuteness of Ouch. For them there is the C<:traditional> interface. Here's how it works:
 
  use Ouch qw(:traditional);
 
@@ -354,6 +389,26 @@ Works exactly like C<kiss>. See C<kiss> for details.
 
 Works exactly like C<hug>. See C<hug> for details.
 
+=head2 Try::Tiny
+
+Many Ouch users, like to use Ouch with L<Try::Tiny>, and some of them are sticks in the mud who can't bring themselves to C<ouch> and C<kiss>, and don't like that C<:traditional> walks all over C<try> and C<catch> For them, there is the C<:trytiny> interface. Here's how it works:
+
+ use Try::Tiny;
+ use Ouch qw(:trytiny);
+
+ try {
+    throw(404, 'File not found!';
+ }
+ catch {
+    if (caught($_)) {
+        # do something
+    }
+    else {
+        throw($_); # rethrow
+    }
+ };
+
+
 =head1 SUPPORT
 
 =over
